diff libpurple/protocols/oscar/oscar.c @ 23320:c200661b5c5c

As XMPP does, prefix away messages with the status name in oscar user info
author Evan Schoenberg <evan.s@dreskin.net>
date Sun, 08 Jun 2008 16:02:46 +0000
parents b3ec26e66e26
children 96dd27f5b45b 81ebe4fac9ce
line wrap: on
line diff
--- a/libpurple/protocols/oscar/oscar.c	Sat Jun 07 20:37:46 2008 +0000
+++ b/libpurple/protocols/oscar/oscar.c	Sun Jun 08 16:02:46 2008 +0000
@@ -871,8 +871,8 @@
 
 	if (b) {
 		if (purple_presence_is_online(presence)) {
-			if (aim_snvalid_icq(b->name) || !message || !(*message)) {
-				/* Append the status name for online ICQ statuses and for all buddies with no message.
+			if (aim_snvalid_icq(b->name) || is_away || !message || !(*message)) {
+				/* Append the status name for online ICQ statuses, away AIM statuses, and for all buddies with no message.
 				 * If the status name and the message are the same, only show one. */
 				const char *status_name = purple_status_get_name(status);
 				if (status_name && message && !strcmp(status_name, message))